@@ -2,10 +2,10 @@ package sanitize
 
 import (
 	"context"
+	netv1 "k8s.io/api/networking/v1"
 
 	"github.com/derailed/popeye/internal"
 	"github.com/derailed/popeye/internal/issues"
-	netv1b1 "k8s.io/api/networking/v1beta1"
 )
 
 type (
@@ -17,7 +17,7 @@ type (
 
 	// IngLister list ingresses.
 	IngLister interface {
-		ListIngresses() map[string]*netv1b1.Ingress
+		ListIngresses() map[string]*netv1.Ingress
 	}
 
 	// IngressLister list available Ingresss on a cluster.
@@ -50,7 +50,7 @@ func (i *Ingress) Sanitize(ctx context.Context) error {
 	return nil
 }
 
-func (i *Ingress) checkDeprecation(ctx context.Context, ing *netv1b1.Ingress) {
+func (i *Ingress) checkDeprecation(ctx context.Context, ing *netv1.Ingress) {
 	const current = "networking.k8s.io/v1"
 	rev, err := resourceRev(internal.MustExtractFQN(ctx), "Ingress", ing.Annotations)
 	if err != nil {
